lilypondfiletools.AttributedBlock
=================================

.. inheritance-diagram:: abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.AttributedBlock
   :private-bases:

.. autoclass:: abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.AttributedBlock

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.AttributedBlock.lilypond_format

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.AttributedBlock.is_formatted_when_empty

Special Methods
---------------

.. automethod:: abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.AttributedBlock.__repr__
